This data was generated using [USQCD](https://www.usqcd.org/) resources. If you use it for your research, please acknowledge [USQCD](https://www.usqcd.org/) resources by adding the following statement to your acknowledgements.

"*The data used in this work was generated using the computing and long-term storage facilities of the USQCD Collaboration, which are funded by the Office of Science of the U.S. Department of Energy.*"
